same

Function same 

pub const fn same<T: Clone>(value: T) -> Same<T>
Creates a generator that always produces the same value.

This is useful for creating parameterized unit tests or for fixing one input to a test while letting others be generated randomly.