pub trait FullGenerate {
type Item;
type Generator: Generate<Item = Self::Item>;
// Required method
fn generator() -> Self::Generator;
}Expand description
When implemented for a type T, this allows to retrieve a generator for T
that does not require any parameter. It should be implemented for any type
that has a canonical way to be generated.
For example, this trait is implemented for all non-pointer primitive types
and for some standard types (such as Option<T> and Result<T, E>).
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.