pub struct Array<T: ?Sized, const N: usize>(pub T);Tuple Fields
0: TTrait Implementations
sourceimpl<G: FullGenerate, const N: usize> FullGenerate for Array<G, N>
impl<G: FullGenerate, const N: usize> FullGenerate for Array<G, N>
sourceimpl<S: FullShrink, const N: usize> FullShrink for Array<S, N>
impl<S: FullShrink, const N: usize> FullShrink for Array<S, N>
sourceimpl<G: Generate + ?Sized, const N: usize> Generate for Array<G, N>
impl<G: Generate + ?Sized, const N: usize> Generate for Array<G, N>
type Item = [<G as Generate>::Item; N]
type Shrink = All<[<G as Generate>::Shrink; N]>
sourcefn generate(&self, state: &mut State) -> Self::Shrink
fn generate(&self, state: &mut State) -> Self::Shrink
Primary method of this trait. It generates a
Shrink instance that will be able to produce values of type
Generate::Item and shrink itself.sourcefn sampler(&self) -> Sampler<'_, Self>
fn sampler(&self) -> Sampler<'_, Self>
Provides a
Sampler that allows to configure sampling settings and generate samples.sourcefn samples(&self, count: usize) -> Samples<'_, Self> ⓘ
fn samples(&self, count: usize) -> Samples<'_, Self> ⓘ
Generates
count random values the are progressively larger in size. For additional sampling settings, see Generate::sampler.sourcefn sample(&self, size: f64) -> Self::Item
fn sample(&self, size: f64) -> Self::Item
Generates a random value of
size (0.0..=1.0). For additional sampling settings, see Generate::sampler.fn checker(&self) -> Checker<'_, Self>
fn checks<P: Prove, F: FnMut(&Self::Item) -> P>( &self, count: usize, check: F, ) -> Checks<'_, Self, F> ⓘ
fn check<P: Prove, F: FnMut(&Self::Item) -> P>( &self, count: usize, check: F, ) -> Result<(), Error<Self::Item, P>>
sourceimpl<G: IntoGenerate, const N: usize> IntoGenerate for Array<G, N>
impl<G: IntoGenerate, const N: usize> IntoGenerate for Array<G, N>