Trait checkito::generate::FullGenerate
source · pub trait FullGenerate {
type Item;
type Generate: Generate<Item = Self::Item>;
// Required method
fn generator() -> Self::Generate;
}Expand description
When implemented for a type T, this allows to retrieve a generator for T that does not require any parameter.
It should be implemented for any type that has a canonical way to be generated.
To provide a generator with parameters, see IntoGenerate.
For example, this trait is implemented for all non-pointer primitive types and for some standard types (such as Option<T> amd Result<T, E>).
Required Associated Types
Required Methods
Object Safety
This trait is not object safe.